##  Introduction
Microsoft Defender for Cloud Apps (MDCA) is Microsoft's cross-platform solution that offers visibility, control, and protection for cloud applications.
  * It provides insights into cloud app usage and risks.
  * It enforces policies to prevent data leakage.
  * It identifies and combats cyber threats to secure cloud applications.


Because of these capabilities, it can be used to identify and catalog all SaaS applications in use, providing visibility into shadow IT and unauthorized app usage.
